==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/components/content/CreateContentDialog.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/components/content/CreateContentDialog.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-state', 'frontend-js-web/liferay/compat/modal/Modal.es', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', '../../store/ConnectedComponent.es', './CreateContentDialog.soy', './CreateContentForm.es', './MapContentForm.es', '../../actions/actions.es', '../../actions/saveChanges.es', '../../actions/updatePageContents.es', '../../utils/FragmentsEditorFetchUtils.es', '../../utils/FragmentsEditorUpdateUtils.es', '../../utils/constants'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.CreateContentDialog = exports.ConnectedCreateContentDialog = void 0;

  var _metalState = require("frontend-js-metal-web$metal-state");

  require("frontend-js-web/liferay/compat/modal/Modal.es");

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _ConnectedComponent = _interopRequireDefault(require("../../store/ConnectedComponent.es"));

  var _CreateContentDialog = _interopRequireDefault(require("./CreateContentDialog.soy"));

  require("./CreateContentForm.es");

  require("./MapContentForm.es");

  var _actions = require("../../actions/actions.es");

  var _saveChanges = require("../../actions/saveChanges.es");

  var _updatePageContents = require("../../actions/updatePageContents.es");

  var _FragmentsEditorFetchUtils = require("../../utils/FragmentsEditorFetchUtils.es");

  var _FragmentsEditorUpdateUtils = require("../../utils/FragmentsEditorUpdateUtils.es");

  var _constants = require("../../utils/constants");

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _toConsumableArray(arr) {
    return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread();
  }

  function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance");
  }

  function _iterableToArray(iter) {
    if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter);
  }

  function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) {
      for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) {
        arr2[i] = arr[i];
      }return arr2;
    }
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(source, true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(source).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * CreateContentDialog
   */
  var CreateContentDialog =
  /*#__PURE__*/
  function (_Component) {
    _inherits(CreateContentDialog, _Component);

    function CreateContentDialog() {
      _classCallCheck(this, CreateContentDialog);

      return _possibleConstructorReturn(this, _getPrototypeOf(CreateContentDialog).apply(this, arguments));
    }

    _createClass(CreateContentDialog, [{
      key: "prepareStateForRender",

      /**
       * @inheritdoc
       * @param {object} state
       * @return {object}
       * @review
       */
      value: function prepareStateForRender(state) {
        var nextState = (0, _FragmentsEditorUpdateUtils.setIn)(state, ['_stepLabel'], Liferay.Util.sub(Liferay.Language.get('step-x-of-x'), state._step, '2'));
        nextState = (0, _FragmentsEditorUpdateUtils.setIn)(nextState, ['_stepName'], Liferay.Language.get('details'));
        return nextState;
      }
      /**
       * Close asset type selection dialog
       * @private
       * @review
       */

    }, {
      key: "_handleCancelButtonClick",
      value: function _handleCancelButtonClick() {
        this.dispose();
      }
      /**
       * Sends mapped content to the server and closes this dialog.
       * @private
       * @review
       */

    }, {
      key: "_handleSubmitButtonClick",
      value: function _handleSubmitButtonClick() {
        var _this = this;

        if (this._step === 1) {
          this._step = 2;
        } else {
          this.store.dispatch((0, _saveChanges.enableSavingChangesStatusAction)());
          (0, _FragmentsEditorFetchUtils.addStructuredContent)(this._serializedFields, this._ddmStructure.id, this._title).then(function (response) {
            var updatedFragmentEntryLinks = {};

            _this._fields.filter(function (field) {
              return field.fragmentEntryLinkId;
            }).forEach(function (field) {
              var fragmentEntryLink = updatedFragmentEntryLinks[field.fragmentEntryLinkId] || _this.fragmentEntryLinks[field.fragmentEntryLinkId];
              var fieldPath = ['editableValues', _constants.EDITABLE_FRAGMENT_ENTRY_PROCESSOR, field.editableId];
              fragmentEntryLink = (0, _FragmentsEditorUpdateUtils.setIn)(fragmentEntryLink, [].concat(fieldPath, ['classNameId']), response.classNameId);
              fragmentEntryLink = (0, _FragmentsEditorUpdateUtils.setIn)(fragmentEntryLink, [].concat(fieldPath, ['classPK']), response.classPK);
              fragmentEntryLink = (0, _FragmentsEditorUpdateUtils.setIn)(fragmentEntryLink, [].concat(fieldPath, ['fieldId']), field.key);
              updatedFragmentEntryLinks[field.fragmentEntryLinkId] = fragmentEntryLink;
            });

            Promise.all(Object.entries(updatedFragmentEntryLinks).map(function (_ref, index) {
              var _ref2 = _slicedToArray(_ref, 2),
                  fragmentEntryLinkId = _ref2[0],
                  fragmentEntryLink = _ref2[1];

              return (0, _FragmentsEditorFetchUtils.updateEditableValues)(fragmentEntryLinkId, fragmentEntryLink.editableValues, index === updatedFragmentEntryLinks.length - 1);
            })).then(function () {
              Object.entries(updatedFragmentEntryLinks).forEach(function (_ref3) {
                var _ref4 = _slicedToArray(_ref3, 2),
                    fragmentEntryLinkId = _ref4[0],
                    fragmentEntryLink = _ref4[1];

                return _this.store.dispatch({
                  editableValues: fragmentEntryLink.editableValues,
                  fragmentEntryLinkId: fragmentEntryLinkId,
                  type: _actions.UPDATE_EDITABLE_VALUE_LOADING
                });
              });

              _this.store.dispatch((0, _updatePageContents.updatePageContentsAction)()).dispatch(_objectSpread({}, response, {
                type: _actions.ADD_MAPPED_ASSET_ENTRY
              })).dispatch((0, _saveChanges.disableSavingChangesStatusAction)()).done(function () {
                return _this.dispose();
              });
            });
          })["catch"](function (error) {
            _this._errorMessage = error.message;

            _this.store.dispatch((0, _saveChanges.disableSavingChangesStatusAction)());
          });
        }
      }
      /**
       * @private
       * @review
       */

    }, {
      key: "_handleCreateContentFormChange",
      value: function _handleCreateContentFormChange(event) {
        var _this2 = this;

        this._ddmStructure = event.ddmStructure;
        this._title = event.title;
        this._valid = event.valid;

        if (this._ddmStructure) {
          (0, _FragmentsEditorFetchUtils.getContentStructureMappingFields)(this._ddmStructure.id).then(function (response) {
            var compatibleTypes = {};
            Object.entries(_constants.COMPATIBLE_TYPES).forEach(function (_ref5) {
              var _ref6 = _slicedToArray(_ref5, 2),
                  editableType = _ref6[0],
                  ddmTypes = _ref6[1];

              ddmTypes.forEach(function (ddmType) {
                compatibleTypes[ddmType] = editableType;
              });
            });
            _this2._fields = [{
              key: '-',
              label: Liferay.Language.get('unmapped'),
              type: '-'
            }].concat(_toConsumableArray(response.map(function (field) {
              return _objectSpread({}, field, {
                type: compatibleTypes[field.type]
              });
            })));
          });
        }
      }
      /**
       * @private
       * @review
       */

    }, {
      key: "_handleMapContentFormFieldsChange",
      value: function _handleMapContentFormFieldsChange(event) {
        if (event.fields) {
          this._fields = event.fields;
          this._serializedFields = event.serializedFields;
        }
      }
      /**
       * Change asset type selection dialog visibility.
       * @private
       * @review
       */

    }, {
      key: "_handleVisibleChanged",
      value: function _handleVisibleChanged() {
        if (!this.visible) {
          this.dispose();
        }
      }
    }]);

    return CreateContentDialog;
  }(_metalComponent["default"]);
  /**
   * State definition.
   * @review
   * @static
   * @type {!Object}
   */

  exports.CreateContentDialog = CreateContentDialog;
  CreateContentDialog.STATE = {
    /**
     * Selected DDM structure
     * @default undefined
     * @instance
     * @memberOf CreateContentDialog
     * @private
     * @review
     * @type {{id: string, label: string}}
     */
    _ddmStructure: _metalState.Config.shapeOf({
      id: _metalState.Config.string().required(),
      label: _metalState.Config.string().required()
    }),

    /**
     * Error message
     * @default ''
     * @instance
     * @memberOf CreateContentDialog
     * @private
     * @review
     * @type {string}
     */
    _errorMessage: _metalState.Config.string().value(null),

    /**
     * List of available structure fields
     * @default null
     * @instance
     * @memberOf CreateContentDialog
     * @private
     * @review
     * @type {Array<{disabled: boolean, editableId: string, fragmentEntryLinkId: string, key: !string, label: !string, type: !string
     * }>}
     */
    _fields: _metalState.Config.arrayOf(_metalState.Config.shapeOf({
      disabled: _metalState.Config.bool().value(false),
      editableId: _metalState.Config.string().value(''),
      fragmentEntryLinkId: _metalState.Config.string().value(null),
      key: _metalState.Config.string().required(),
      label: _metalState.Config.string().required(),
      type: _metalState.Config.string().required()
    })).internal().value(null),

    /**
     * Serialized DDM form fields
     * @default ''
     * @instance
     * @memberOf CreateContentDialog
     * @private
     * @review
     * @type {string}
     */
    _serializedFields: _metalState.Config.string().value(''),

    /**
     * Current dialog step
     * @default 1
     * @instance
     * @memberOf CreateContentDialog
     * @private
     * @review
     * @type {number}
     */
    _step: _metalState.Config.number().value(1),

    /**
     * Current content title
     * @default ''
     * @instance
     * @memberOf CreateContentDialog
     * @private
     * @review
     * @type {string}
     */
    _title: _metalState.Config.string().value(''),

    /**
     * Is form valid
     * @default false
     * @instance
     * @memberOf CreateContentForm
     * @private
     * @review
     * @type {boolean}
     */
    _valid: _metalState.Config.bool().value(false)
  };
  var ConnectedCreateContentDialog = (0, _ConnectedComponent["default"])(CreateContentDialog, ['fragmentEntryLinks', 'portletNamespace', 'savingChanges', 'spritemap']);
  exports.ConnectedCreateContentDialog = ConnectedCreateContentDialog;

  _metalSoy["default"].register(ConnectedCreateContentDialog, _CreateContentDialog["default"]);

  var _default = ConnectedCreateContentDialog;
  exports["default"] = _default;
  //# sourceMappingURL=CreateContentDialog.es.js.map
});
//# sourceMappingURL=CreateContentDialog.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.126.jar: META-INF/resources/js/components/content/CreateContentDialog.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.126/js/components/content/CreateContentDialog.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-state', 'frontend-js-web/liferay/compat/modal/Modal.es', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', '../../store/ConnectedComponent.es', './CreateContentDialog.soy', './CreateContentForm.es', './MapContentForm.es', '../../actions/actions.es', '../../actions/saveChanges.es', '../../actions/updatePageContents.es', '../../utils/FragmentsEditorFetchUtils.es', '../../utils/FragmentsEditorUpdateUtils.es', '../../utils/constants'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.CreateContentDialog = exports.ConnectedCreateContentDialog = void 0;

  var _metalState = require("frontend-js-metal-web$metal-state");

  require("frontend-js-web/liferay/compat/modal/Modal.es");

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _ConnectedComponent = _interopRequireDefault(require("../../store/ConnectedComponent.es"));

  var _CreateContentDialog = _interopRequireDefault(require("./CreateContentDialog.soy"));

  require("./CreateContentForm.es");

  require("./MapContentForm.es");

  var _actions = require("../../actions/actions.es");

  var _saveChanges = require("../../actions/saveChanges.es");

  var _updatePageContents = require("../../actions/updatePageContents.es");

  var _FragmentsEditorFetchUtils = require("../../utils/FragmentsEditorFetchUtils.es");

  var _FragmentsEditorUpdateUtils = require("../../utils/FragmentsEditorUpdateUtils.es");

  var _constants = require("../../utils/constants");

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _toConsumableArray(arr) {
    return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread();
  }

  function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance");
  }

  function _iterableToArray(iter) {
    if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter);
  }

  function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) {
      for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) {
        arr2[i] = arr[i];
      }return arr2;
    }
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
      return;
    }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * CreateContentDialog
   */
  var CreateContentDialog = /*#__PURE__*/function (_Component) {
    _inherits(CreateContentDialog, _Component);

    function CreateContentDialog() {
      _classCallCheck(this, CreateContentDialog);

      return _possibleConstructorReturn(this, _getPrototypeOf(CreateContentDialog).apply(this, arguments));
    }

    _createClass(CreateContentDialog, [{
      key: "prepareStateForRender",

      /**
       * @inheritdoc
       * @param {object} state
       * @return {object}
       * @review
       */
      value: function prepareStateForRender(state) {
        var nextState = (0, _FragmentsEditorUpdateUtils.setIn)(state, ['_stepLabel'], Liferay.Util.sub(Liferay.Language.get('step-x-of-x'), state._step, '2'));
        nextState = (0, _FragmentsEditorUpdateUtils.setIn)(nextState, ['_stepName'], Liferay.Language.get('details'));
        return nextState;
      }
      /**
       * Close asset type selection dialog
       * @private
       * @review
       */

    }, {
      key: "_handleCancelButtonClick",
      value: function _handleCancelButtonClick() {
        this.dispose();
      }
      /**
       * Sends mapped content to the server and closes this dialog.
       * @private
       * @review
       */

    }, {
      key: "_handleSubmitButtonClick",
      value: function _handleSubmitButtonClick() {
        var _this = this;

        if (this._step === 1) {
          this._step = 2;
        } else {
          this.store.dispatch((0, _saveChanges.enableSavingChangesStatusAction)());
          (0, _FragmentsEditorFetchUtils.addStructuredContent)(this._serializedFields, this._ddmStructure.id, this._title).then(function (response) {
            var updatedFragmentEntryLinks = {};

            _this._fields.filter(function (field) {
              return field.fragmentEntryLinkId;
            }).forEach(function (field) {
              var fragmentEntryLink = updatedFragmentEntryLinks[field.fragmentEntryLinkId] || _this.fragmentEntryLinks[field.fragmentEntryLinkId];
              var fieldPath = ['editableValues', _constants.EDITABLE_FRAGMENT_ENTRY_PROCESSOR, field.editableId];
              fragmentEntryLink = (0, _FragmentsEditorUpdateUtils.setIn)(fragmentEntryLink, [].concat(fieldPath, ['classNameId']), response.classNameId);
              fragmentEntryLink = (0, _FragmentsEditorUpdateUtils.setIn)(fragmentEntryLink, [].concat(fieldPath, ['classPK']), response.classPK);
              fragmentEntryLink = (0, _FragmentsEditorUpdateUtils.setIn)(fragmentEntryLink, [].concat(fieldPath, ['fieldId']), field.key);
              updatedFragmentEntryLinks[field.fragmentEntryLinkId] = fragmentEntryLink;
            });

            Promise.all(Object.entries(updatedFragmentEntryLinks).map(function (_ref, index) {
              var _ref2 = _slicedToArray(_ref, 2),
                  fragmentEntryLinkId = _ref2[0],
                  fragmentEntryLink = _ref2[1];

              return (0, _FragmentsEditorFetchUtils.updateEditableValues)(fragmentEntryLinkId, fragmentEntryLink.editableValues, index === updatedFragmentEntryLinks.length - 1);
            })).then(function () {
              Object.entries(updatedFragmentEntryLinks).forEach(function (_ref3) {
                var _ref4 = _slicedToArray(_ref3, 2),
                    fragmentEntryLinkId = _ref4[0],
                    fragmentEntryLink = _ref4[1];

                return _this.store.dispatch({
                  editableValues: fragmentEntryLink.editableValues,
                  fragmentEntryLinkId: fragmentEntryLinkId,
                  type: _actions.UPDATE_EDITABLE_VALUE_LOADING
                });
              });

              _this.store.dispatch((0, _updatePageContents.updatePageContentsAction)()).dispatch(_objectSpread({}, response, {
                type: _actions.ADD_MAPPED_ASSET_ENTRY
              })).dispatch((0, _saveChanges.disableSavingChangesStatusAction)()).done(function () {
                return _this.dispose();
              });
            });
          })["catch"](function (error) {
            _this._errorMessage = error.message;

            _this.store.dispatch((0, _saveChanges.disableSavingChangesStatusAction)());
          });
        }
      }
      /**
       * @private
       * @review
       */

    }, {
      key: "_handleCreateContentFormChange",
      value: function _handleCreateContentFormChange(event) {
        var _this2 = this;

        this._ddmStructure = event.ddmStructure;
        this._title = event.title;
        this._valid = event.valid;

        if (this._ddmStructure) {
          (0, _FragmentsEditorFetchUtils.getContentStructureMappingFields)(this._ddmStructure.id).then(function (response) {
            var compatibleTypes = {};
            Object.entries(_constants.COMPATIBLE_TYPES).forEach(function (_ref5) {
              var _ref6 = _slicedToArray(_ref5, 2),
                  editableType = _ref6[0],
                  ddmTypes = _ref6[1];

              ddmTypes.forEach(function (ddmType) {
                compatibleTypes[ddmType] = editableType;
              });
            });
            _this2._fields = [{
              key: '-',
              label: Liferay.Language.get('unmapped'),
              type: '-'
            }].concat(_toConsumableArray(response.map(function (field) {
              return _objectSpread({}, field, {
                type: compatibleTypes[field.type]
              });
            })));
          });
        }
      }
      /**
       * @private
       * @review
       */

    }, {
      key: "_handleMapContentFormFieldsChange",
      value: function _handleMapContentFormFieldsChange(event) {
        if (event.fields) {
          this._fields = event.fields;
          this._serializedFields = event.serializedFields;
        }
      }
      /**
       * Change asset type selection dialog visibility.
       * @private
       * @review
       */

    }, {
      key: "_handleVisibleChanged",
      value: function _handleVisibleChanged() {
        if (!this.visible) {
          this.dispose();
        }
      }
    }]);

    return CreateContentDialog;
  }(_metalComponent["default"]);
  /**
   * State definition.
   * @review
   * @static
   * @type {!Object}
   */

  exports.CreateContentDialog = CreateContentDialog;
  CreateContentDialog.STATE = {
    /**
     * Selected DDM structure
     * @default undefined
     * @instance
     * @memberOf CreateContentDialog
     * @private
     * @review
     * @type {{id: string, label: string}}
     */
    _ddmStructure: _metalState.Config.shapeOf({
      id: _metalState.Config.string().required(),
      label: _metalState.Config.string().required()
    }),

    /**
     * Error message
     * @default ''
     * @instance
     * @memberOf CreateContentDialog
     * @private
     * @review
     * @type {string}
     */
    _errorMessage: _metalState.Config.string().value(null),

    /**
     * List of available structure fields
     * @default null
     * @instance
     * @memberOf CreateContentDialog
     * @private
     * @review
     * @type {Array<{disabled: boolean, editableId: string, fragmentEntryLinkId: string, key: !string, label: !string, type: !string
     * }>}
     */
    _fields: _metalState.Config.arrayOf(_metalState.Config.shapeOf({
      disabled: _metalState.Config.bool().value(false),
      editableId: _metalState.Config.string().value(''),
      fragmentEntryLinkId: _metalState.Config.string().value(null),
      key: _metalState.Config.string().required(),
      label: _metalState.Config.string().required(),
      type: _metalState.Config.string().required()
    })).internal().value(null),

    /**
     * Serialized DDM form fields
     * @default ''
     * @instance
     * @memberOf CreateContentDialog
     * @private
     * @review
     * @type {string}
     */
    _serializedFields: _metalState.Config.string().value(''),

    /**
     * Current dialog step
     * @default 1
     * @instance
     * @memberOf CreateContentDialog
     * @private
     * @review
     * @type {number}
     */
    _step: _metalState.Config.number().value(1),

    /**
     * Current content title
     * @default ''
     * @instance
     * @memberOf CreateContentDialog
     * @private
     * @review
     * @type {string}
     */
    _title: _metalState.Config.string().value(''),

    /**
     * Is form valid
     * @default false
     * @instance
     * @memberOf CreateContentForm
     * @private
     * @review
     * @type {boolean}
     */
    _valid: _metalState.Config.bool().value(false)
  };
  var ConnectedCreateContentDialog = (0, _ConnectedComponent["default"])(CreateContentDialog, ['fragmentEntryLinks', 'portletNamespace', 'savingChanges', 'spritemap']);
  exports.ConnectedCreateContentDialog = ConnectedCreateContentDialog;

  _metalSoy["default"].register(ConnectedCreateContentDialog, _CreateContentDialog["default"]);

  var _default = ConnectedCreateContentDialog;
  exports["default"] = _default;
  //# sourceMappingURL=CreateContentDialog.es.js.map
});
//# sourceMappingURL=CreateContentDialog.es.js.map
